@@ -16,11 +16,11 @@ if [[ "$#" -lt 1 ]]; then
   exit 1
 fi
 
-find "$1" -type f -executable -exec file -i '{}' \; | grep -e 'application/x-sharedlib; charset=binary' -e 'application/x-pie-executable; charset=binary' -e 'application/x-executable; charset=binary'  | cut -c1- | cut -d ':' -f1 > linux_executables.txt
+find "$1" -type f -executable -exec file -i '{}' \; | grep -e 'application/x-sharedlib; charset=binary' -e 'application/x-pie-executable; charset=binary' -e 'application/x-executable; charset=binary' | cut -c1- | cut -d ':' -f1 > linux_executables.txt
 
 echo "Checksec Output" | tee "$2"
 
-for i in $(cat linux_executables.txt); do
+while read -r i; do
   ./checksec &> /dev/null
   if [ "$?" -eq 127 ]; then
     echo "File not Found. Keep checksec in same directory and run the script again."
@@ -28,4 +28,4 @@ for i in $(cat linux_executables.txt); do
   else
     ./checksec --file="$i" | tee -a "$2"
   fi
-done
+done < <(cat linux_executables.txt)
